@@ -34,3 +34,6 @@ class Underline(Selector):
         self.content = resp.text
         self.document = BeautifulSoup(resp.content, "html.parser")
 
+    def to_selector(self, el):
+        return Selector(self.document, el, self.url)
+
